<?php
namespace Teknisa\FAI\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\Report\ReportService;
use Zeedhi\Framework\DB\StoredProcedure\Param;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;

class RelacionamentoClienteServicoRelatorio extends \Zeedhi\Framework\Controller\Report {

	protected $birtStrategy;
	protected $environment;
	protected $newCode;
	protected $connection;

	public function __construct($reportService, $newCode, $birtStrategy, $environment, $connection) {
		parent::__construct($reportService);
		
		$this->newCode      = $newCode;
		$this->birtStrategy = $birtStrategy;
		$this->environment  = $environment;
		$this->connection  	= $connection;
	}
	
	
		protected $reportMapping = array (
		'FAI00600' =>
		array (
			'strategy' => 'BIRT',
			'parameterMapping' =>
			array (
				'CDFILIAL'		=> 'P_CDFILIAL',
				'CDCLIENTE'		=> 'P_CDCLIENTE',
				'CDSERVFILI'	=> 'P_CDSERVFILI',
				'NRORG'     	=> 'P_NRORG',
				'CDOPERADOR'	=> 'P_CDOPERADOR'
			)
		),
		'FAI00601' =>
		array (
			'strategy' => 'BIRT',
			'parameterMapping' =>
			array (
				'CDFILIAL'		=> 'P_CDFILIAL',
				'CDCLIENTE' 	=> 'P_CDCLIENTE',
				'CDSERVFILI'	=> 'P_CDSERVFILI',
				'NRORG'     	=> 'P_NRORG',
				'CDOPERADOR'	=> 'P_CDOPERADOR'
			)
		),
		'FAI00602' =>
		array (
			'strategy' => 'BIRT',
			'parameterMapping' =>
			array (
				'CDFILIAL'		=> 'P_CDFILIAL',
				'CDCLIENTE' 	=> 'P_CDCLIENTE',
				'CDSERVFILI'	=> 'P_CDSERVFILI',
				'NRORG'     	=> 'P_NRORG',
				'CDOPERADOR'	=> 'P_CDOPERADOR'
			)
		),
		'FAI00603' =>
		array (
			'strategy' => 'BIRT',
			'parameterMapping' =>
			array (
				'CDFILIAL'  	=> 'P_CDFILIAL',
				'CDCLIENTE' 	=> 'P_CDCLIENTE',
				'CDSERVFILI'	=> 'P_CDSERVFILI',
				'NRORG'     	=> 'P_NRORG',
				'CDOPERADOR'	=> 'P_CDOPERADOR'
			)
		)
	);

	public function beforeProcessReport(DTO\Request\Row $request, DTO\Response $response) {
		$row = $request->getRow();
		
		$row['CDOPERADOR'] = $this->environment->getCdOperador();
		$row['NRORG'] = $this->environment->getNrOrg();
		is_array($row['CDFILIAL']) ? $row['CDFILIAL'] = $this->criarListaValores(implode('_', $row['CDFILIAL'])) : $row['CDFILIAL'] = 'T';
		is_array($row['CDCLIENTE']) ? $row['CDCLIENTE'] = $this->criarListaValores(implode('_', $row['CDCLIENTE'])) : $row['CDCLIENTE'] = 'T';
		is_array($row['CDSERVFILI']) ? $row['CDSERVFILI'] = $this->criarListaValores(implode('_', $row['CDSERVFILI'])) : $row['CDSERVFILI'] = 'T';
	
		$this->birtStrategy->setReportFormat(strtolower($row['QR2TYPE']));
	}

	public function criarListaValores($valores){
        if(strlen($valores) <= 4000){
            return $valores;
        }else{
            $lista = explode('_',$valores);
            $nrlista = $this->newCode->getCodeByTableName('LISTA', $this->environment->getNrorgTrab(), 1, 10, false);
            try{
                foreach($lista as $key){
                    $this->insertLista($nrlista, $key);
                }
                return "_NRLISTA=".$nrlista;
            } catch(\Exception $e){
                throw $e;
            }
        }
    }
    
    public function insertLista($nrlista, $cdlista) {
        $params = array(
            "NRLISTA" => $nrlista,
            "CDLISTA" => $cdlista,
            "NRORG" => $this->environment->getNrorgTrab()
        );
        
        $sql = "INSERT INTO LISTA (NRLISTA, CDLISTA, NRORG) VALUES (:NRLISTA, :CDLISTA, :NRORG)";
        $query = $this->connection->prepare($sql);
        $query->execute($params);
    }

}
